# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from signrpc import signer_pb2 as signrpc_dot_signer__pb2
from walletrpc import walletkit_pb2 as walletrpc_dot_walletkit__pb2


class WalletKitStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.DeriveNextKey = channel.unary_unary(
        '/walletrpc.WalletKit/DeriveNextKey',
        request_serializer=walletrpc_dot_walletkit__pb2.KeyReq.SerializeToString,
        response_deserializer=signrpc_dot_signer__pb2.KeyDescriptor.FromString,
        )
    self.DeriveKey = channel.unary_unary(
        '/walletrpc.WalletKit/DeriveKey',
        request_serializer=signrpc_dot_signer__pb2.KeyLocator.SerializeToString,
        response_deserializer=signrpc_dot_signer__pb2.KeyDescriptor.FromString,
        )
    self.NextAddr = channel.unary_unary(
        '/walletrpc.WalletKit/NextAddr',
        request_serializer=walletrpc_dot_walletkit__pb2.AddrRequest.SerializeToString,
        response_deserializer=walletrpc_dot_walletkit__pb2.AddrResponse.FromString,
        )
    self.PublishTransaction = channel.unary_unary(
        '/walletrpc.WalletKit/PublishTransaction',
        request_serializer=walletrpc_dot_walletkit__pb2.Transaction.SerializeToString,
        response_deserializer=walletrpc_dot_walletkit__pb2.PublishResponse.FromString,
        )
    self.SendOutputs = channel.unary_unary(
        '/walletrpc.WalletKit/SendOutputs',
        request_serializer=walletrpc_dot_walletkit__pb2.SendOutputsRequest.SerializeToString,
        response_deserializer=walletrpc_dot_walletkit__pb2.SendOutputsResponse.FromString,
        )
    self.EstimateFee = channel.unary_unary(
        '/walletrpc.WalletKit/EstimateFee',
        request_serializer=walletrpc_dot_walletkit__pb2.EstimateFeeRequest.SerializeToString,
        response_deserializer=walletrpc_dot_walletkit__pb2.EstimateFeeResponse.FromString,
        )


class WalletKitServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def DeriveNextKey(self, request, context):
    """*
    DeriveNextKey attempts to derive the *next* key within the key family
    (account in BIP43) specified. This method should return the next external
    child within this branch.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeriveKey(self, request, context):
    """*
    DeriveKey attempts to derive an arbitrary key specified by the passed
    KeyLocator. 
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def NextAddr(self, request, context):
    """*
    NextAddr returns the next unused address within the wallet.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PublishTransaction(self, request, context):
    """*
    PublishTransaction attempts to publish the passed transaction to the
    network. Once this returns without an error, the wallet will continually
    attempt to re-broadcast the transaction on start up, until it enters the
    chain.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SendOutputs(self, request, context):
    """*
    SendOutputs is similar to the existing sendmany call in Bitcoind, and
    allows the caller to create a transaction that sends to several outputs at
    once. This is ideal when wanting to batch create a set of transactions.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EstimateFee(self, request, context):
    """*
    EstimateFee attempts to query the internal fee estimator of the wallet to
    determine the fee (in sat/kw) to attach to a transaction in order to
    achieve the confirmation target.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_WalletKitServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'DeriveNextKey': grpc.unary_unary_rpc_method_handler(
          servicer.DeriveNextKey,
          request_deserializer=walletrpc_dot_walletkit__pb2.KeyReq.FromString,
          response_serializer=signrpc_dot_signer__pb2.KeyDescriptor.SerializeToString,
      ),
      'DeriveKey': grpc.unary_unary_rpc_method_handler(
          servicer.DeriveKey,
          request_deserializer=signrpc_dot_signer__pb2.KeyLocator.FromString,
          response_serializer=signrpc_dot_signer__pb2.KeyDescriptor.SerializeToString,
      ),
      'NextAddr': grpc.unary_unary_rpc_method_handler(
          servicer.NextAddr,
          request_deserializer=walletrpc_dot_walletkit__pb2.AddrRequest.FromString,
          response_serializer=walletrpc_dot_walletkit__pb2.AddrResponse.SerializeToString,
      ),
      'PublishTransaction': grpc.unary_unary_rpc_method_handler(
          servicer.PublishTransaction,
          request_deserializer=walletrpc_dot_walletkit__pb2.Transaction.FromString,
          response_serializer=walletrpc_dot_walletkit__pb2.PublishResponse.SerializeToString,
      ),
      'SendOutputs': grpc.unary_unary_rpc_method_handler(
          servicer.SendOutputs,
          request_deserializer=walletrpc_dot_walletkit__pb2.SendOutputsRequest.FromString,
          response_serializer=walletrpc_dot_walletkit__pb2.SendOutputsResponse.SerializeToString,
      ),
      'EstimateFee': grpc.unary_unary_rpc_method_handler(
          servicer.EstimateFee,
          request_deserializer=walletrpc_dot_walletkit__pb2.EstimateFeeRequest.FromString,
          response_serializer=walletrpc_dot_walletkit__pb2.EstimateFeeResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'walletrpc.WalletKit', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: walletrpc/walletkit.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from signrpc import signer_pb2 as signrpc_dot_signer__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='walletrpc/walletkit.proto',
  package='walletrpc',
  syntax='proto3',
  serialized_options=_b('Z.github.com/lncm/lnd-rpc/v0.6.1/lnrpc/walletrpc'),
  serialized_pb=_b('\n\x19walletrpc/walletkit.proto\x12\twalletrpc\x1a\x14signrpc/signer.proto\"6\n\x06KeyReq\x12\x18\n\x10key_finger_print\x18\x01 \x01(\x05\x12\x12\n\nkey_family\x18\x02 \x01(\x05\"\r\n\x0b\x41\x64\x64rRequest\"\x1c\n\x0c\x41\x64\x64rResponse\x12\x0c\n\x04\x61\x64\x64r\x18\x01 \x01(\t\"\x1d\n\x0bTransaction\x12\x0e\n\x06tx_hex\x18\x01 \x01(\x0c\"(\n\x0fPublishResponse\x12\x15\n\rpublish_error\x18\x01 \x01(\t\"I\n\x12SendOutputsRequest\x12\x12\n\nsat_per_kw\x18\x01 \x01(\x03\x12\x1f\n\x07outputs\x18\x02 \x03(\x0b\x32\x0e.signrpc.TxOut\"%\n\x13SendOutputsResponse\x12\x0e\n\x06raw_tx\x18\x01 \x01(\x0c\")\n\x12\x45stimateFeeRequest\x12\x13\n\x0b\x63onf_target\x18\x01 \x01(\x05\")\n\x13\x45stimateFeeResponse\x12\x12\n\nsat_per_kw\x18\x01 \x01(\x03\x32\xa4\x03\n\tWalletKit\x12:\n\rDeriveNextKey\x12\x11.walletrpc.KeyReq\x1a\x16.signrpc.KeyDescriptor\x12\x38\n\tDeriveKey\x12\x13.signrpc.KeyLocator\x1a\x16.signrpc.KeyDescriptor\x12;\n\x08NextAddr\x12\x16.walletrpc.AddrRequest\x1a\x17.walletrpc.AddrResponse\x12H\n\x12PublishTransaction\x12\x16.walletrpc.Transaction\x1a\x1a.walletrpc.PublishResponse\x12L\n\x0bSendOutputs\x12\x1d.walletrpc.SendOutputsRequest\x1a\x1e.walletrpc.SendOutputsResponse\x12L\n\x0b\x45stimateFee\x12\x1d.walletrpc.EstimateFeeRequest\x1a\x1e.walletrpc.EstimateFeeResponseB0Z.github.com/lncm/lnd-rpc/v0.6.1/lnrpc/walletrpcb\x06proto3')
  ,
  dependencies=[signrpc_dot_signer__pb2.DESCRIPTOR,])




_KEYREQ = _descriptor.Descriptor(
  name='KeyReq',
  full_name='walletrpc.KeyReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_finger_print', full_name='walletrpc.KeyReq.key_finger_print', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key_family', full_name='walletrpc.KeyReq.key_family', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=116,
)


_ADDRREQUEST = _descriptor.Descriptor(
  name='AddrRequest',
  full_name='walletrpc.AddrRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=118,
  serialized_end=131,
)


_ADDRRESPONSE = _descriptor.Descriptor(
  name='AddrResponse',
  full_name='walletrpc.AddrResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='addr', full_name='walletrpc.AddrResponse.addr', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=133,
  serialized_end=161,
)


_TRANSACTION = _descriptor.Descriptor(
  name='Transaction',
  full_name='walletrpc.Transaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx_hex', full_name='walletrpc.Transaction.tx_hex', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=163,
  serialized_end=192,
)


_PUBLISHRESPONSE = _descriptor.Descriptor(
  name='PublishResponse',
  full_name='walletrpc.PublishResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='publish_error', full_name='walletrpc.PublishResponse.publish_error', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=194,
  serialized_end=234,
)


_SENDOUTPUTSREQUEST = _descriptor.Descriptor(
  name='SendOutputsRequest',
  full_name='walletrpc.SendOutputsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sat_per_kw', full_name='walletrpc.SendOutputsRequest.sat_per_kw', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outputs', full_name='walletrpc.SendOutputsRequest.outputs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=236,
  serialized_end=309,
)


_SENDOUTPUTSRESPONSE = _descriptor.Descriptor(
  name='SendOutputsResponse',
  full_name='walletrpc.SendOutputsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='raw_tx', full_name='walletrpc.SendOutputsResponse.raw_tx', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=311,
  serialized_end=348,
)


_ESTIMATEFEEREQUEST = _descriptor.Descriptor(
  name='EstimateFeeRequest',
  full_name='walletrpc.EstimateFeeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='conf_target', full_name='walletrpc.EstimateFeeRequest.conf_target', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=350,
  serialized_end=391,
)


_ESTIMATEFEERESPONSE = _descriptor.Descriptor(
  name='EstimateFeeResponse',
  full_name='walletrpc.EstimateFeeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sat_per_kw', full_name='walletrpc.EstimateFeeResponse.sat_per_kw', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=393,
  serialized_end=434,
)

_SENDOUTPUTSREQUEST.fields_by_name['outputs'].message_type = signrpc_dot_signer__pb2._TXOUT
DESCRIPTOR.message_types_by_name['KeyReq'] = _KEYREQ
DESCRIPTOR.message_types_by_name['AddrRequest'] = _ADDRREQUEST
DESCRIPTOR.message_types_by_name['AddrResponse'] = _ADDRRESPONSE
DESCRIPTOR.message_types_by_name['Transaction'] = _TRANSACTION
DESCRIPTOR.message_types_by_name['PublishResponse'] = _PUBLISHRESPONSE
DESCRIPTOR.message_types_by_name['SendOutputsRequest'] = _SENDOUTPUTSREQUEST
DESCRIPTOR.message_types_by_name['SendOutputsResponse'] = _SENDOUTPUTSRESPONSE
DESCRIPTOR.message_types_by_name['EstimateFeeRequest'] = _ESTIMATEFEEREQUEST
DESCRIPTOR.message_types_by_name['EstimateFeeResponse'] = _ESTIMATEFEERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

KeyReq = _reflection.GeneratedProtocolMessageType('KeyReq', (_message.Message,), dict(
  DESCRIPTOR = _KEYREQ,
  __module__ = 'walletrpc.walletkit_pb2'
  # @@protoc_insertion_point(class_scope:walletrpc.KeyReq)
  ))
_sym_db.RegisterMessage(KeyReq)

AddrRequest = _reflection.GeneratedProtocolMessageType('AddrRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDRREQUEST,
  __module__ = 'walletrpc.walletkit_pb2'
  # @@protoc_insertion_point(class_scope:walletrpc.AddrRequest)
  ))
_sym_db.RegisterMessage(AddrRequest)

AddrResponse = _reflection.GeneratedProtocolMessageType('AddrResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDRRESPONSE,
  __module__ = 'walletrpc.walletkit_pb2'
  # @@protoc_insertion_point(class_scope:walletrpc.AddrResponse)
  ))
_sym_db.RegisterMessage(AddrResponse)

Transaction = _reflection.GeneratedProtocolMessageType('Transaction', (_message.Message,), dict(
  DESCRIPTOR = _TRANSACTION,
  __module__ = 'walletrpc.walletkit_pb2'
  # @@protoc_insertion_point(class_scope:walletrpc.Transaction)
  ))
_sym_db.RegisterMessage(Transaction)

PublishResponse = _reflection.GeneratedProtocolMessageType('PublishResponse', (_message.Message,), dict(
  DESCRIPTOR = _PUBLISHRESPONSE,
  __module__ = 'walletrpc.walletkit_pb2'
  # @@protoc_insertion_point(class_scope:walletrpc.PublishResponse)
  ))
_sym_db.RegisterMessage(PublishResponse)

SendOutputsRequest = _reflection.GeneratedProtocolMessageType('SendOutputsRequest', (_message.Message,), dict(
  DESCRIPTOR = _SENDOUTPUTSREQUEST,
  __module__ = 'walletrpc.walletkit_pb2'
  # @@protoc_insertion_point(class_scope:walletrpc.SendOutputsRequest)
  ))
_sym_db.RegisterMessage(SendOutputsRequest)

SendOutputsResponse = _reflection.GeneratedProtocolMessageType('SendOutputsResponse', (_message.Message,), dict(
  DESCRIPTOR = _SENDOUTPUTSRESPONSE,
  __module__ = 'walletrpc.walletkit_pb2'
  # @@protoc_insertion_point(class_scope:walletrpc.SendOutputsResponse)
  ))
_sym_db.RegisterMessage(SendOutputsResponse)

EstimateFeeRequest = _reflection.GeneratedProtocolMessageType('EstimateFeeRequest', (_message.Message,), dict(
  DESCRIPTOR = _ESTIMATEFEEREQUEST,
  __module__ = 'walletrpc.walletkit_pb2'
  # @@protoc_insertion_point(class_scope:walletrpc.EstimateFeeRequest)
  ))
_sym_db.RegisterMessage(EstimateFeeRequest)

EstimateFeeResponse = _reflection.GeneratedProtocolMessageType('EstimateFeeResponse', (_message.Message,), dict(
  DESCRIPTOR = _ESTIMATEFEERESPONSE,
  __module__ = 'walletrpc.walletkit_pb2'
  # @@protoc_insertion_point(class_scope:walletrpc.EstimateFeeResponse)
  ))
_sym_db.RegisterMessage(EstimateFeeResponse)


DESCRIPTOR._options = None

_WALLETKIT = _descriptor.ServiceDescriptor(
  name='WalletKit',
  full_name='walletrpc.WalletKit',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=437,
  serialized_end=857,
  methods=[
  _descriptor.MethodDescriptor(
    name='DeriveNextKey',
    full_name='walletrpc.WalletKit.DeriveNextKey',
    index=0,
    containing_service=None,
    input_type=_KEYREQ,
    output_type=signrpc_dot_signer__pb2._KEYDESCRIPTOR,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeriveKey',
    full_name='walletrpc.WalletKit.DeriveKey',
    index=1,
    containing_service=None,
    input_type=signrpc_dot_signer__pb2._KEYLOCATOR,
    output_type=signrpc_dot_signer__pb2._KEYDESCRIPTOR,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='NextAddr',
    full_name='walletrpc.WalletKit.NextAddr',
    index=2,
    containing_service=None,
    input_type=_ADDRREQUEST,
    output_type=_ADDRRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PublishTransaction',
    full_name='walletrpc.WalletKit.PublishTransaction',
    index=3,
    containing_service=None,
    input_type=_TRANSACTION,
    output_type=_PUBLISHRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SendOutputs',
    full_name='walletrpc.WalletKit.SendOutputs',
    index=4,
    containing_service=None,
    input_type=_SENDOUTPUTSREQUEST,
    output_type=_SENDOUTPUTSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='EstimateFee',
    full_name='walletrpc.WalletKit.EstimateFee',
    index=5,
    containing_service=None,
    input_type=_ESTIMATEFEEREQUEST,
    output_type=_ESTIMATEFEERESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_WALLETKIT)

DESCRIPTOR.services_by_name['WalletKit'] = _WALLETKIT

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from autopilotrpc import autopilot_pb2 as autopilotrpc_dot_autopilot__pb2


class AutopilotStub(object):
  """Autopilot is a service that can be used to get information about the current
  state of the daemon's autopilot agent, and also supply it with information
  that can be used when deciding where to open channels.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Status = channel.unary_unary(
        '/autopilotrpc.Autopilot/Status',
        request_serializer=autopilotrpc_dot_autopilot__pb2.StatusRequest.SerializeToString,
        response_deserializer=autopilotrpc_dot_autopilot__pb2.StatusResponse.FromString,
        )
    self.ModifyStatus = channel.unary_unary(
        '/autopilotrpc.Autopilot/ModifyStatus',
        request_serializer=autopilotrpc_dot_autopilot__pb2.ModifyStatusRequest.SerializeToString,
        response_deserializer=autopilotrpc_dot_autopilot__pb2.ModifyStatusResponse.FromString,
        )
    self.QueryScores = channel.unary_unary(
        '/autopilotrpc.Autopilot/QueryScores',
        request_serializer=autopilotrpc_dot_autopilot__pb2.QueryScoresRequest.SerializeToString,
        response_deserializer=autopilotrpc_dot_autopilot__pb2.QueryScoresResponse.FromString,
        )
    self.SetScores = channel.unary_unary(
        '/autopilotrpc.Autopilot/SetScores',
        request_serializer=autopilotrpc_dot_autopilot__pb2.SetScoresRequest.SerializeToString,
        response_deserializer=autopilotrpc_dot_autopilot__pb2.SetScoresResponse.FromString,
        )


class AutopilotServicer(object):
  """Autopilot is a service that can be used to get information about the current
  state of the daemon's autopilot agent, and also supply it with information
  that can be used when deciding where to open channels.
  """

  def Status(self, request, context):
    """*
    Status returns whether the daemon's autopilot agent is active.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ModifyStatus(self, request, context):
    """*
    ModifyStatus is used to modify the status of the autopilot agent, like
    enabling or disabling it.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def QueryScores(self, request, context):
    """*
    QueryScores queries all available autopilot heuristics, in addition to any
    active combination of these heruristics, for the scores they would give to
    the given nodes.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetScores(self, request, context):
    """*
    SetScores attempts to set the scores used by the running autopilot agent,
    if the external scoring heuristic is enabled.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_AutopilotServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Status': grpc.unary_unary_rpc_method_handler(
          servicer.Status,
          request_deserializer=autopilotrpc_dot_autopilot__pb2.StatusRequest.FromString,
          response_serializer=autopilotrpc_dot_autopilot__pb2.StatusResponse.SerializeToString,
      ),
      'ModifyStatus': grpc.unary_unary_rpc_method_handler(
          servicer.ModifyStatus,
          request_deserializer=autopilotrpc_dot_autopilot__pb2.ModifyStatusRequest.FromString,
          response_serializer=autopilotrpc_dot_autopilot__pb2.ModifyStatusResponse.SerializeToString,
      ),
      'QueryScores': grpc.unary_unary_rpc_method_handler(
          servicer.QueryScores,
          request_deserializer=autopilotrpc_dot_autopilot__pb2.QueryScoresRequest.FromString,
          response_serializer=autopilotrpc_dot_autopilot__pb2.QueryScoresResponse.SerializeToString,
      ),
      'SetScores': grpc.unary_unary_rpc_method_handler(
          servicer.SetScores,
          request_deserializer=autopilotrpc_dot_autopilot__pb2.SetScoresRequest.FromString,
          response_serializer=autopilotrpc_dot_autopilot__pb2.SetScoresResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'autopilotrpc.Autopilot', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from signrpc import signer_pb2 as signrpc_dot_signer__pb2


class SignerStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.SignOutputRaw = channel.unary_unary(
        '/signrpc.Signer/SignOutputRaw',
        request_serializer=signrpc_dot_signer__pb2.SignReq.SerializeToString,
        response_deserializer=signrpc_dot_signer__pb2.SignResp.FromString,
        )
    self.ComputeInputScript = channel.unary_unary(
        '/signrpc.Signer/ComputeInputScript',
        request_serializer=signrpc_dot_signer__pb2.SignReq.SerializeToString,
        response_deserializer=signrpc_dot_signer__pb2.InputScriptResp.FromString,
        )


class SignerServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def SignOutputRaw(self, request, context):
    """*
    SignOutputRaw is a method that can be used to generated a signature for a
    set of inputs/outputs to a transaction. Each request specifies details
    concerning how the outputs should be signed, which keys they should be
    signed with, and also any optional tweaks. The return value is a fixed
    64-byte signature (the same format as we use on the wire in Lightning). 

    If we are  unable to sign using the specified keys, then an error will be
    returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ComputeInputScript(self, request, context):
    """*
    ComputeInputScript generates a complete InputIndex for the passed
    transaction with the signature as defined within the passed SignDescriptor.
    This method should be capable of generating the proper input script for
    both regular p2wkh output and p2wkh outputs nested within a regular p2sh
    output.

    Note that when using this method to sign inputs belonging to the wallet,
    the only items of the SignDescriptor that need to be populated are pkScript
    in the TxOut field, the value in that same field, and finally the input
    index.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_SignerServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'SignOutputRaw': grpc.unary_unary_rpc_method_handler(
          servicer.SignOutputRaw,
          request_deserializer=signrpc_dot_signer__pb2.SignReq.FromString,
          response_serializer=signrpc_dot_signer__pb2.SignResp.SerializeToString,
      ),
      'ComputeInputScript': grpc.unary_unary_rpc_method_handler(
          servicer.ComputeInputScript,
          request_deserializer=signrpc_dot_signer__pb2.SignReq.FromString,
          response_serializer=signrpc_dot_signer__pb2.InputScriptResp.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'signrpc.Signer', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: routerrpc/router.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='routerrpc/router.proto',
  package='routerrpc',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x16routerrpc/router.proto\x12\trouterrpc\"\x82\x01\n\x0ePaymentRequest\x12\x0f\n\x07pay_req\x18\x01 \x01(\t\x12\x15\n\rfee_limit_sat\x18\x02 \x01(\x03\x12\x12\n\ncltv_limit\x18\x03 \x01(\x05\x12\x17\n\x0ftimeout_seconds\x18\x04 \x01(\x05\x12\x1b\n\x13outgoing_channel_id\x18\x05 \x01(\x03\"K\n\x0fPaymentResponse\x12\x10\n\x08pay_hash\x18\x01 \x01(\x0c\x12\x11\n\tpre_image\x18\x02 \x01(\x0c\x12\x13\n\x0bpayment_err\x18\x03 \x01(\t\"0\n\x0fRouteFeeRequest\x12\x0c\n\x04\x64\x65st\x18\x01 \x01(\x0c\x12\x0f\n\x07\x61mt_sat\x18\x02 \x01(\x03\"E\n\x10RouteFeeResponse\x12\x18\n\x10routing_fee_msat\x18\x01 \x01(\x03\x12\x17\n\x0ftime_lock_delay\x18\x02 \x01(\x03\x32\x9b\x01\n\x06Router\x12\x44\n\x0bSendPayment\x12\x19.routerrpc.PaymentRequest\x1a\x1a.routerrpc.PaymentResponse\x12K\n\x10\x45stimateRouteFee\x12\x1a.routerrpc.RouteFeeRequest\x1a\x1b.routerrpc.RouteFeeResponseb\x06proto3')
)




_PAYMENTREQUEST = _descriptor.Descriptor(
  name='PaymentRequest',
  full_name='routerrpc.PaymentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pay_req', full_name='routerrpc.PaymentRequest.pay_req', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fee_limit_sat', full_name='routerrpc.PaymentRequest.fee_limit_sat', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cltv_limit', full_name='routerrpc.PaymentRequest.cltv_limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeout_seconds', full_name='routerrpc.PaymentRequest.timeout_seconds', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outgoing_channel_id', full_name='routerrpc.PaymentRequest.outgoing_channel_id', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=38,
  serialized_end=168,
)


_PAYMENTRESPONSE = _descriptor.Descriptor(
  name='PaymentResponse',
  full_name='routerrpc.PaymentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pay_hash', full_name='routerrpc.PaymentResponse.pay_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pre_image', full_name='routerrpc.PaymentResponse.pre_image', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payment_err', full_name='routerrpc.PaymentResponse.payment_err', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=170,
  serialized_end=245,
)


_ROUTEFEEREQUEST = _descriptor.Descriptor(
  name='RouteFeeRequest',
  full_name='routerrpc.RouteFeeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dest', full_name='routerrpc.RouteFeeRequest.dest', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amt_sat', full_name='routerrpc.RouteFeeRequest.amt_sat', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=247,
  serialized_end=295,
)


_ROUTEFEERESPONSE = _descriptor.Descriptor(
  name='RouteFeeResponse',
  full_name='routerrpc.RouteFeeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='routing_fee_msat', full_name='routerrpc.RouteFeeResponse.routing_fee_msat', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_lock_delay', full_name='routerrpc.RouteFeeResponse.time_lock_delay', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=297,
  serialized_end=366,
)

DESCRIPTOR.message_types_by_name['PaymentRequest'] = _PAYMENTREQUEST
DESCRIPTOR.message_types_by_name['PaymentResponse'] = _PAYMENTRESPONSE
DESCRIPTOR.message_types_by_name['RouteFeeRequest'] = _ROUTEFEEREQUEST
DESCRIPTOR.message_types_by_name['RouteFeeResponse'] = _ROUTEFEERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PaymentRequest = _reflection.GeneratedProtocolMessageType('PaymentRequest', (_message.Message,), dict(
  DESCRIPTOR = _PAYMENTREQUEST,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.PaymentRequest)
  ))
_sym_db.RegisterMessage(PaymentRequest)

PaymentResponse = _reflection.GeneratedProtocolMessageType('PaymentResponse', (_message.Message,), dict(
  DESCRIPTOR = _PAYMENTRESPONSE,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.PaymentResponse)
  ))
_sym_db.RegisterMessage(PaymentResponse)

RouteFeeRequest = _reflection.GeneratedProtocolMessageType('RouteFeeRequest', (_message.Message,), dict(
  DESCRIPTOR = _ROUTEFEEREQUEST,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.RouteFeeRequest)
  ))
_sym_db.RegisterMessage(RouteFeeRequest)

RouteFeeResponse = _reflection.GeneratedProtocolMessageType('RouteFeeResponse', (_message.Message,), dict(
  DESCRIPTOR = _ROUTEFEERESPONSE,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.RouteFeeResponse)
  ))
_sym_db.RegisterMessage(RouteFeeResponse)



_ROUTER = _descriptor.ServiceDescriptor(
  name='Router',
  full_name='routerrpc.Router',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=369,
  serialized_end=524,
  methods=[
  _descriptor.MethodDescriptor(
    name='SendPayment',
    full_name='routerrpc.Router.SendPayment',
    index=0,
    containing_service=None,
    input_type=_PAYMENTREQUEST,
    output_type=_PAYMENTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='EstimateRouteFee',
    full_name='routerrpc.Router.EstimateRouteFee',
    index=1,
    containing_service=None,
    input_type=_ROUTEFEEREQUEST,
    output_type=_ROUTEFEERESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_ROUTER)

DESCRIPTOR.services_by_name['Router'] = _ROUTER

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from routerrpc import router_pb2 as routerrpc_dot_router__pb2


class RouterStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.SendPayment = channel.unary_unary(
        '/routerrpc.Router/SendPayment',
        request_serializer=routerrpc_dot_router__pb2.PaymentRequest.SerializeToString,
        response_deserializer=routerrpc_dot_router__pb2.PaymentResponse.FromString,
        )
    self.EstimateRouteFee = channel.unary_unary(
        '/routerrpc.Router/EstimateRouteFee',
        request_serializer=routerrpc_dot_router__pb2.RouteFeeRequest.SerializeToString,
        response_deserializer=routerrpc_dot_router__pb2.RouteFeeResponse.FromString,
        )


class RouterServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def SendPayment(self, request, context):
    """*
    SendPayment attempts to route a payment described by the passed
    PaymentRequest to the final destination. If we are unable to route the
    payment, or cannot find a route that satisfies the constraints in the
    PaymentRequest, then an error will be returned. Otherwise, the payment
    pre-image, along with the final route will be returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EstimateRouteFee(self, request, context):
    """*
    EstimateRouteFee allows callers to obtain a lower bound w.r.t how much it
    may cost to send an HTLC to the target end destination.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_RouterServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'SendPayment': grpc.unary_unary_rpc_method_handler(
          servicer.SendPayment,
          request_deserializer=routerrpc_dot_router__pb2.PaymentRequest.FromString,
          response_serializer=routerrpc_dot_router__pb2.PaymentResponse.SerializeToString,
      ),
      'EstimateRouteFee': grpc.unary_unary_rpc_method_handler(
          servicer.EstimateRouteFee,
          request_deserializer=routerrpc_dot_router__pb2.RouteFeeRequest.FromString,
          response_serializer=routerrpc_dot_router__pb2.RouteFeeResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'routerrpc.Router', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
